Crate numbat_wasm_module_users

Crate numbat_wasm_module_users 

Modules

endpoints

Structs

AbiProvider
ContractObj

Traits

AutoImpl
EndpointWrappers
ProxyTrait
UsersModule
The module deals with temporarily pausing contract operations. It provides a flag that contracts can use to check if owner decided to users the entire contract. Use the features module for more granular on/off switches.

Functions

contract_obj